import React, { useState, useEffect } from 'react';
import {FormComponent} from '@formbird/types';
import { convertToCustomElement } from '../utils/CustomElementWrapper';
import { createStyles, makeStyles, Theme } from '@material-ui/core/styles';
import InputLabel from '@material-ui/core/InputLabel';
import MenuItem from '@material-ui/core/MenuItem';
import FormHelperText from '@material-ui/core/FormHelperText';
import FormControl from '@material-ui/core/FormControl';
import Select from '@material-ui/core/Select';
import { changedDocumentService } from '../services';

const useStyles = makeStyles((theme: Theme) =>
  createStyles({
    formControl: {
      margin: theme.spacing(1),
      minWidth: 120,
    },
    selectEmpty: {
      marginTop: theme.spacing(2),
    },
  }),
);

const ReTestDropDownComponent = ({
  document,
  fieldValue,
  template,
  fieldName,
  formParameters,
  key,
  responsiveLayouts,
  message,
  componentDefinition
}) => {
  const classes = useStyles();

  const [value, setValue] = useState(fieldValue);

  const [age, setAge] = React.useState('');

  const handleChange = (event: React.ChangeEvent<{ value: unknown }>) => {
    setValue(event.target.value);

    changedDocumentService.valueChanged({
      document,
      fieldName,
      fieldValue,
      formParameters,
      template,
      componentDefinition,
      key
    }, event.target.value);
  };

  useEffect(() => {
    if (fieldValue) {
      setValue(fieldValue);
    } else if (componentDefinition.defaultValue) {
      setValue(componentDefinition.defaultValue);
    }
  }, []);

  return (
    <div>
    <FormControl className={classes.formControl}>
      <InputLabel id="demo-simple-select-label">Age</InputLabel>
      <Select
        labelId="demo-simple-select-label"
        id="demo-simple-select"
        value={value}
        onChange={handleChange}
      >
        {/* {if (componentDefinition.dropDownList) {
          componentDefinition.dropDownList.map(function(item, i){
            <MenuItem value={item[i]}>{item[i]}</MenuItem>
          }
        }
        } */}
      </Select>
    </FormControl>
  </div>
  );
};

// register the component as a custom element so it can be shown in formbird
convertToCustomElement('re-test-drop-down', ReTestDropDownComponent);

export default ReTestDropDownComponent;
